Geodyn
Author: Geodynamo - ISTerre
Description: Visualisations tools for geomagnetic data

#### <<<

Home page

#### Visualisations

On Earth's core surface projections
Magnetic field and flow
Cross-sections
Time series along Θ or Φ
Time series of spherical harmonic coefficients
Evolution in time of the length-of-day variation
Computed from core flows
Lowes-Mauersberger spectra
Observatories data
Ground-based or Virtual
Options
Loading ...
Scientific contact
nicolas.gillet@univ-grenoble-alpes.fr
Technical contact
franck.thollard@univ-grenoble-alpes.fr
loic.huder@univ-grenoble-alpes.fr